==> church_of_jesus_christ_api-0.2.3.tar.gz: church_of_jesus_christ_api-0.2.3/doc/source/JSON_schemas/get_member_callings_and_classes-schema.md <==
{
  authorizedToEditCallings: bool,
  authorizedToEditClassAssignments: bool,
  classAssignments: [
    {
      adultClass: bool,
      classId: int,
      className: str,
      classTypeId: int,
      defaultClass: bool,
      defaultClassTypeId: int,
      group: str,
      individualId: int,
      organization: str
    }
  ],
  householdCallings: list,
  individualCallings: [
    {
      activeDate: str,
      allowApprove: bool,
      allowMultiple: bool,
      allowNew: bool,
      allowVacant: bool,
      approvalRequest: bool,
      autoReleasedPositionTypeIds: NoneType,
      canHaveResponsibilities: bool,
      contactEmail: str,
      contactInfoEditable: bool,
      contactMailingAddr: NoneType,
      contactMobilePhone: NoneType,
      contactWorkPhone: NoneType,
      custom: bool,
      customNameChanged: bool,
      dualAuthPass: NoneType,
      dualAuthUser: NoneType,
      editable: bool,
      errors: {},
      expectedEndDate: NoneType,
      hasContactInfo: bool,
      hidden: bool,
      memberEmail: str,
      memberId: int,
      memberName: str,
      memberNameOrder: int,
      memberPhone: NoneType,
      memberUnitName: NoneType,
      memberUnitNumber: NoneType,
      missionName: NoneType,
      missionUnitNumber: NoneType,
      missionary: bool,
      missionaryHomeUnitName: NoneType,
      mrn: NoneType,
      nameVerificationForMrn: NoneType,
      newSubOrgId: NoneType,
      ordainDate: NoneType,
      ordainedByPersonId: NoneType,
      ordainedByPersonMrn: NoneType,
      ordainedByPersonName: NoneType,
      organization: str,
      otherAllowedSubOrgs: [
        {
          children: list,
          classGroup: NoneType,
          defaultOrgTypeIds: [
            int
          ],
          firstTypeId: int,
          gender: NoneType,
          isClass: bool,
          isCombined: bool,
          isRealClass: bool,
          isSplit: bool,
          name: str,
          orgTypeIds: [
            int
          ],
          parentName: str,
          subOrgId: int,
          unitNumber: int,
          userCanEditCallings: bool
        }
      ],
      parentOrganization: NoneType,
      pendingCalling: bool,
      pendingDelete: bool,
      pendingDualAuth: bool,
      position: str,
      positionDisplayOrder: int,
      positionId: int,
      positionTypeEnum: str,
      positionTypeId: int,
      previouslyOrdained: bool,
      releaseDate: NoneType,
      releasePositionIds: NoneType,
      requiresBishopOrdination: bool,
      requiresDualAuthorization: bool,
      requiresSetApartDateAndPerson: bool,
      responsibilities: NoneType,
      sequence: int,
      setApart: bool,
      setApartByPersonId: NoneType,
      setApartByPersonMrn: NoneType,
      setApartByPersonName: NoneType,
      setApartDate: NoneType,
      showUnitCard: bool,
      subOrgId: int,
      subOrgTypeId: int,
      unitName: str,
      unitNumber: int,
      unpublished: bool,
      userCanEdit: bool,
      userCanEditContactInfoOnly: bool,
      userCannotEditPreviousOrdination: bool,
      vacant: bool
    }
  ],
  subOrgsForPotentialNewCallings: [
    {
      children: list,
      classGroup: NoneType,
      defaultOrgTypeIds: [
        int
      ],
      firstTypeId: int,
      gender: NoneType,
      isClass: bool,
      isCombined: bool,
      isRealClass: bool,
      isSplit: bool,
      name: str,
      orgTypeIds: [
        int
      ],
      parentName: str,
      subOrgId: int,
      unitNumber: int,
      userCanEditCallings: bool
    }
  ]
}

==> church_of_jesus_christ_api-0.2.8.tar.gz: church_of_jesus_christ_api-0.2.8/doc/source/JSON_schemas/get_member_callings_and_classes-schema.md <==
{
  authorizedToEditCallings: bool,
  authorizedToEditClassAssignments: bool,
  classAssignments: [
    {
      adultClass: bool,
      classId: int,
      className: str,
      classTypeId: int,
      defaultClass: bool,
      defaultClassTypeId: int,
      group: str,
      individualId: int,
      organization: str
    }
  ],
  householdCallings: [
    {
      activeDate: str,
      allowApprove: bool,
      allowMultiple: bool,
      allowNew: bool,
      allowVacant: bool,
      approvalRequest: bool,
      autoReleasedPositionTypeIds: NoneType,
      canHaveResponsibilities: bool,
      contactEmail: str,
      contactInfoEditable: bool,
      contactMailingAddr: NoneType,
      contactMobilePhone: NoneType,
      contactWorkPhone: NoneType,
      custom: bool,
      customNameChanged: bool,
      dualAuthPass: NoneType,
      dualAuthUser: NoneType,
      editable: bool,
      errors: {},
      expectedEndDate: NoneType,
      hasContactInfo: bool,
      hidden: bool,
      memberEmail: NoneType,
      memberId: int,
      memberName: str,
      memberNameOrder: int,
      memberPhone: NoneType,
      memberUnitName: NoneType,
      memberUnitNumber: NoneType,
      missionName: NoneType,
      missionUnitNumber: NoneType,
      missionary: bool,
      missionaryHomeUnitName: NoneType,
      mrn: str,
      nameVerificationForMrn: NoneType,
      newSubOrgId: NoneType,
      ordainDate: NoneType,
      ordainedByPersonId: NoneType,
      ordainedByPersonMrn: NoneType,
      ordainedByPersonName: NoneType,
      organization: str,
      otherAllowedSubOrgs: [
        {
          children: list,
          classGroup: NoneType,
          defaultOrgTypeIds: [
            int
          ],
          firstTypeId: int,
          gender: NoneType,
          isClass: bool,
          isCombined: bool,
          isRealClass: bool,
          isSplit: bool,
          name: str,
          orgTypeIds: [
            int
          ],
          parentName: str,
          subOrgId: int,
          unitNumber: int,
          userCanEditCallings: bool
        }
      ],
      parentOrganization: NoneType,
      pendingCalling: bool,
      pendingDelete: bool,
      pendingDualAuth: bool,
      position: str,
      positionDisplayOrder: int,
      positionId: int,
      positionTypeEnum: str,
      positionTypeId: int,
      previouslyOrdained: bool,
      releaseDate: NoneType,
      releasePositionIds: NoneType,
      requiresBishopOrdination: bool,
      requiresDualAuthorization: bool,
      requiresSetApartDateAndPerson: bool,
      responsibilities: NoneType,
      sequence: int,
      setApart: bool,
      setApartByPersonId: NoneType,
      setApartByPersonMrn: NoneType,
      setApartByPersonName: NoneType,
      setApartDate: str,
      showUnitCard: bool,
      subOrgId: int,
      subOrgTypeId: int,
      unitName: str,
      unitNumber: int,
      unpublished: bool,
      userCanEdit: bool,
      userCanEditContactInfoOnly: bool,
      userCannotEditPreviousOrdination: bool,
      vacant: bool
    }
  ],
  individualCallings: [
    {
      activeDate: str,
      allowApprove: bool,
      allowMultiple: bool,
      allowNew: bool,
      allowVacant: bool,
      approvalRequest: bool,
      autoReleasedPositionTypeIds: NoneType,
      canHaveResponsibilities: bool,
      contactEmail: str,
      contactInfoEditable: bool,
      contactMailingAddr: NoneType,
      contactMobilePhone: NoneType,
      contactWorkPhone: NoneType,
      custom: bool,
      customNameChanged: bool,
      dualAuthPass: NoneType,
      dualAuthUser: NoneType,
      editable: bool,
      errors: {},
      expectedEndDate: NoneType,
      hasContactInfo: bool,
      hidden: bool,
      memberEmail: str,
      memberId: int,
      memberName: str,
      memberNameOrder: int,
      memberPhone: NoneType,
      memberUnitName: NoneType,
      memberUnitNumber: NoneType,
      missionName: NoneType,
      missionUnitNumber: NoneType,
      missionary: bool,
      missionaryHomeUnitName: NoneType,
      mrn: str,
      nameVerificationForMrn: NoneType,
      newSubOrgId: NoneType,
      ordainDate: NoneType,
      ordainedByPersonId: NoneType,
      ordainedByPersonMrn: NoneType,
      ordainedByPersonName: NoneType,
      organization: str,
      otherAllowedSubOrgs: [
        {
          children: list,
          classGroup: NoneType,
          defaultOrgTypeIds: [
            int
          ],
          firstTypeId: int,
          gender: NoneType,
          isClass: bool,
          isCombined: bool,
          isRealClass: bool,
          isSplit: bool,
          name: str,
          orgTypeIds: [
            int
          ],
          parentName: str,
          subOrgId: int,
          unitNumber: int,
          userCanEditCallings: bool
        }
      ],
      parentOrganization: NoneType,
      pendingCalling: bool,
      pendingDelete: bool,
      pendingDualAuth: bool,
      position: str,
      positionDisplayOrder: int,
      positionId: int,
      positionTypeEnum: str,
      positionTypeId: int,
      previouslyOrdained: bool,
      releaseDate: NoneType,
      releasePositionIds: NoneType,
      requiresBishopOrdination: bool,
      requiresDualAuthorization: bool,
      requiresSetApartDateAndPerson: bool,
      responsibilities: NoneType,
      sequence: int,
      setApart: bool,
      setApartByPersonId: NoneType,
      setApartByPersonMrn: NoneType,
      setApartByPersonName: NoneType,
      setApartDate: NoneType,
      showUnitCard: bool,
      subOrgId: int,
      subOrgTypeId: int,
      unitName: str,
      unitNumber: int,
      unpublished: bool,
      userCanEdit: bool,
      userCanEditContactInfoOnly: bool,
      userCannotEditPreviousOrdination: bool,
      vacant: bool
    }
  ],
  subOrgsForPotentialNewCallings: [
    {
      children: list,
      classGroup: NoneType,
      defaultOrgTypeIds: [
        int
      ],
      firstTypeId: int,
      gender: NoneType,
      isClass: bool,
      isCombined: bool,
      isRealClass: bool,
      isSplit: bool,
      name: str,
      orgTypeIds: [
        int
      ],
      parentName: NoneType,
      subOrgId: int,
      unitNumber: int,
      userCanEditCallings: bool
    }
  ]
}
